
package com.mobula.sample;

import com.duapps.ad.AbsInterstitialListener;
import com.duapps.ad.DuNativeAd;
import com.duapps.ad.InterstitialAd;
import com.duapps.ad.PullRequestController;
import com.duapps.ad.offerwall.ui.OfferWallAct;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

/**
 * the main page 主页
 * 
 * @author mobula team
 */
public class MainActivity extends Activity implements OnClickListener {
	private static final String TAG = MainActivity.class.getSimpleName();
	/**
	 * fill the advertising button 填充按钮
	 */
	private Button mFillAdBtn;
	/**
	 * display ads button 展示广告按钮
	 */
	private Button mShowAdBtn;
	/**
	 * clean ads cache data 清除广告内存数据按钮
	 */
	private Button mCleanCacheBtn;
	/**
	 * offerwall button view 广告墙按钮
	 */
	private Button mOfferwall;
	
	/**
	 * Interstitial button view 插屏广告按钮
	 */
	private Button mInterstitialAd;
	
	/**
	 * mobula ad data mobula广告数据类
	 */
	private DuNativeAd nativeAd;
	/**
	 * ad recommend id 广告推荐位
	 */
	private static final int PID = 10032;
	/**
	 * cache data size 缓存大小
	 */
	private static final int CACHESZIE = 2;
	private InterstitialAd iad;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main_layout);

		initViews();
		initListeners();
	}

	/**
	 * initialize the view method 初始化视图
	 */
	private void initViews() {
		mFillAdBtn = (Button) findViewById(R.id.fill_ad);
		mShowAdBtn = (Button) findViewById(R.id.show_ad);
		mCleanCacheBtn = (Button) findViewById(R.id.clean_ad);
		mOfferwall = (Button) findViewById(R.id.offerwall);
		mInterstitialAd = (Button) findViewById(R.id.Interstitial_ad);
	}

	/**
	 * register to listen event method 注册监听事件
	 */
	private void initListeners() {
		mFillAdBtn.setOnClickListener(this);
		mShowAdBtn.setOnClickListener(this);
		mCleanCacheBtn.setOnClickListener(this);
		mOfferwall.setOnClickListener(this);
		mInterstitialAd.setOnClickListener(this);
	}

	@Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fill_ad:
                nativeAd = new DuNativeAd(this, PID, CACHESZIE);
                nativeAd.fill();
                Toast.makeText(this, "Fill the advertising", Toast.LENGTH_LONG).show();
                break;

            case R.id.show_ad:
                Intent intent = new Intent(this, ShowAdActivity.class);
                startActivity(intent);
                break;
                
            case R.id.clean_ad:
                PullRequestController.getInstance(getApplicationContext()).clearCache();
                Toast.makeText(this, "clean cache data success", Toast.LENGTH_LONG).show();
                break;
                
            case R.id.offerwall:
            	Intent intent1 = new Intent(MainActivity.this, OfferWallAct.class);
    			Bundle b = new Bundle();
    			b.putInt("pid", 10032); 
    			intent1.putExtras(b);
    			startActivity(intent1);
    			break;
            case R.id.Interstitial_ad:
            	mInterstitialAd.setEnabled(false);
            	mInterstitialAd.setClickable(false);
            	showAsPopup();
            	break;
            default:
                break;
        }
    }
    
    //创建插屏广告对象,设置插屏广告ID
	private InterstitialAd getIAD() {
        if (iad == null) {
            iad = new InterstitialAd(this, PID,InterstitialAd.Type.SCREEN);
        }
        return iad;
    }
	
	@Override
    protected void onDestroy() {
        super.onDestroy();
        if (null != iad) {
            iad.destory();
        }
    }
	
	@Override
    protected void onStop() {
        super.onStop();
        if (null != iad) {
            iad.close();
        }
    }
	
	private void showAsPopup() {	
        getIAD().setInterstitialListener(new AbsInterstitialListener() {

            @Override
            public void onAdFail(int errcode) {
                Log.d(TAG, "call to onAdFail, errorcode(" + errcode + ")");
                MainActivity.this.runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                    	mInterstitialAd.setEnabled(true);
                    	mInterstitialAd.setClickable(true);
                    }
                });
            }

            @Override
            public void onAdReceive() {
                iad.show();
                Log.d(TAG, "call to onAdReceive()!");
                MainActivity.this.runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                    	mInterstitialAd.setEnabled(true);
                    	mInterstitialAd.setClickable(true);
                    }
                });
            }
        });
        iad.load();
    }
}
